--
-- fifo_if_types
--
-- Interfacing types for FIFOs

library IEEE;
use IEEE.std_logic_1164.all;

library work;
use work.fifo.all;
use work.ocpad.all;
use work.fifo_if_types.all;
use work.localbus_if_types.all;
use work.slave_bus_if_types.all;

package ocp_pcietgt is


  component localbus2ocp_pcietgt_bridge_r64b128
   generic (
    number_of_ocp_nonburst : integer := 7;
    number_of_ddma_engines : integer := 1;
    number_of_ocp_burst_per_engine : integer := 4;
    la_top           : natural := 23;
    family           : family_t := family_virtex4);
  port (
    lclk             : in    std_logic;  -- Local Bus Clock
    ocp_clk_nb       : in    std_logic;  -- Non-Burst Clock
    ocp_clk_b        : in    std_logic;  -- Burst Clock
    rst              : out   std_logic;  -- Global Reset (LRESET)
    -- OCP Interfaces
    ocp_nonburst_bus_outputs_array         : out ocpad_register64_m2sT_array(0 to number_of_ocp_nonburst-1);
    ocp_nonburst_bus_inputs_array          : in  ocpad_register64_s2mT_array(0 to number_of_ocp_nonburst-1);
    ocp_burst_bus_outputs_array         : out ocpad_burst128_m2sT_array(0 to number_of_ocp_burst_per_engine*number_of_ddma_engines-1);
    ocp_burst_bus_inputs_array          : in  ocpad_burst128_s2mT_array(0 to number_of_ocp_burst_per_engine*number_of_ddma_engines-1);
    -- Local Bus Interface
    localbus_inputs  : in  localbus_inputs_type;
    localbus_outputs : out localbus_outputs_type;
    system_status    : in  std_logic_vector(31 downto 0);
    system_irq       : in  std_logic_vector(31 downto 0);
    irq              : out std_logic;
    -- PCIe Interface
    pcie_tx_p        : out std_logic_vector(7 downto 0);
    pcie_tx_n        : out std_logic_vector(7 downto 0);
    pcie_rx_p        : in  std_logic_vector(7 downto 0);
    pcie_rx_n        : in  std_logic_vector(7 downto 0);
    pcie_clk_p       : in  std_logic;
    pcie_clk_n       : in  std_logic;
    pcie_rst_n       : in  std_logic);
  end component;

  
end ocp_pcietgt;
